==> zio-aws-iotwireless_2.13-5.17.201.1-sources.jar: zio/aws/iotwireless/model/UpdateResourceEventConfigurationRequest.scala <==
package zio.aws.iotwireless.model
import zio.aws.iotwireless.model.primitives.Identifier
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateResourceEventConfigurationRequest(
    identifier: Identifier,
    identifierType: zio.aws.iotwireless.model.IdentifierType,
    partnerType: Optional[
      zio.aws.iotwireless.model.EventNotificationPartnerType
    ] = Optional.Absent,
    deviceRegistrationState: Optional[
      zio.aws.iotwireless.model.DeviceRegistrationStateEventConfiguration
    ] = Optional.Absent,
    proximity: Optional[zio.aws.iotwireless.model.ProximityEventConfiguration] =
      Optional.Absent,
    join: Optional[zio.aws.iotwireless.model.JoinEventConfiguration] =
      Optional.Absent,
    connectionStatus: Optional[
      zio.aws.iotwireless.model.ConnectionStatusEventConfiguration
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotwireless.model.UpdateResourceEventConfigurationRequest = {
    import UpdateResourceEventConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotwireless.model.UpdateResourceEventConfigurationRequest
      .builder()
      .identifier(Identifier.unwrap(identifier): java.lang.String)
      .identifierType(identifierType.unwrap)
      .optionallyWith(partnerType.map(value => value.unwrap))(_.partnerType)
      .optionallyWith(
        deviceRegistrationState.map(value => value.buildAwsValue())
      )(_.deviceRegistrationState)
      .optionallyWith(proximity.map(value => value.buildAwsValue()))(
        _.proximity
      )
      .optionallyWith(join.map(value => value.buildAwsValue()))(_.join)
      .optionallyWith(connectionStatus.map(value => value.buildAwsValue()))(
        _.connectionStatus
      )
      .build()
  }
  def asReadOnly
      : zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest.ReadOnly =
    zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateResourceEventConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotwireless.model.UpdateResourceEventConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest =
      zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest(
        identifier,
        identifierType,
        partnerType.map(value => value),
        deviceRegistrationState.map(value => value.asEditable),
        proximity.map(value => value.asEditable),
        join.map(value => value.asEditable),
        connectionStatus.map(value => value.asEditable)
      )
    def identifier: Identifier
    def identifierType: zio.aws.iotwireless.model.IdentifierType
    def partnerType
        : Optional[zio.aws.iotwireless.model.EventNotificationPartnerType]
    def deviceRegistrationState: Optional[
      zio.aws.iotwireless.model.DeviceRegistrationStateEventConfiguration.ReadOnly
    ]
    def proximity: Optional[
      zio.aws.iotwireless.model.ProximityEventConfiguration.ReadOnly
    ]
    def join
        : Optional[zio.aws.iotwireless.model.JoinEventConfiguration.ReadOnly]
    def connectionStatus: Optional[
      zio.aws.iotwireless.model.ConnectionStatusEventConfiguration.ReadOnly
    ]
    def getIdentifier: ZIO[Any, Nothing, Identifier] = ZIO.succeed(identifier)
    def getIdentifierType
        : ZIO[Any, Nothing, zio.aws.iotwireless.model.IdentifierType] =
      ZIO.succeed(identifierType)
    def getPartnerType: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.EventNotificationPartnerType
    ] = AwsError.unwrapOptionField("partnerType", partnerType)
    def getDeviceRegistrationState: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.DeviceRegistrationStateEventConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "deviceRegistrationState",
      deviceRegistrationState
    )
    def getProximity: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.ProximityEventConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("proximity", proximity)
    def getJoin: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.JoinEventConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("join", join)
    def getConnectionStatus: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.ConnectionStatusEventConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("connectionStatus", connectionStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotwireless.model.UpdateResourceEventConfigurationRequest
  ) extends zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest.ReadOnly {
    override val identifier: Identifier =
      zio.aws.iotwireless.model.primitives.Identifier(impl.identifier())
    override val identifierType: zio.aws.iotwireless.model.IdentifierType =
      zio.aws.iotwireless.model.IdentifierType.wrap(impl.identifierType())
    override val partnerType
        : Optional[zio.aws.iotwireless.model.EventNotificationPartnerType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.partnerType())
        .map(value =>
          zio.aws.iotwireless.model.EventNotificationPartnerType.wrap(value)
        )
    override val deviceRegistrationState: Optional[
      zio.aws.iotwireless.model.DeviceRegistrationStateEventConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.deviceRegistrationState())
      .map(value =>
        zio.aws.iotwireless.model.DeviceRegistrationStateEventConfiguration
          .wrap(value)
      )
    override val proximity: Optional[
      zio.aws.iotwireless.model.ProximityEventConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.proximity())
      .map(value =>
        zio.aws.iotwireless.model.ProximityEventConfiguration.wrap(value)
      )
    override val join
        : Optional[zio.aws.iotwireless.model.JoinEventConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.join())
        .map(value =>
          zio.aws.iotwireless.model.JoinEventConfiguration.wrap(value)
        )
    override val connectionStatus: Optional[
      zio.aws.iotwireless.model.ConnectionStatusEventConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.connectionStatus())
      .map(value =>
        zio.aws.iotwireless.model.ConnectionStatusEventConfiguration.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotwireless.model.UpdateResourceEventConfigurationRequest
  ): zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iotwireless_2.13-7.21.15.12-sources.jar: zio/aws/iotwireless/model/UpdateResourceEventConfigurationRequest.scala <==
package zio.aws.iotwireless.model
import zio.aws.iotwireless.model.primitives.Identifier
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class UpdateResourceEventConfigurationRequest(
    identifier: Identifier,
    identifierType: zio.aws.iotwireless.model.IdentifierType,
    partnerType: Optional[
      zio.aws.iotwireless.model.EventNotificationPartnerType
    ] = Optional.Absent,
    deviceRegistrationState: Optional[
      zio.aws.iotwireless.model.DeviceRegistrationStateEventConfiguration
    ] = Optional.Absent,
    proximity: Optional[zio.aws.iotwireless.model.ProximityEventConfiguration] =
      Optional.Absent,
    join: Optional[zio.aws.iotwireless.model.JoinEventConfiguration] =
      Optional.Absent,
    connectionStatus: Optional[
      zio.aws.iotwireless.model.ConnectionStatusEventConfiguration
    ] = Optional.Absent,
    messageDeliveryStatus: Optional[
      zio.aws.iotwireless.model.MessageDeliveryStatusEventConfiguration
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotwireless.model.UpdateResourceEventConfigurationRequest = {
    import UpdateResourceEventConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotwireless.model.UpdateResourceEventConfigurationRequest
      .builder()
      .identifier(Identifier.unwrap(identifier): java.lang.String)
      .identifierType(identifierType.unwrap)
      .optionallyWith(partnerType.map(value => value.unwrap))(_.partnerType)
      .optionallyWith(
        deviceRegistrationState.map(value => value.buildAwsValue())
      )(_.deviceRegistrationState)
      .optionallyWith(proximity.map(value => value.buildAwsValue()))(
        _.proximity
      )
      .optionallyWith(join.map(value => value.buildAwsValue()))(_.join)
      .optionallyWith(connectionStatus.map(value => value.buildAwsValue()))(
        _.connectionStatus
      )
      .optionallyWith(
        messageDeliveryStatus.map(value => value.buildAwsValue())
      )(_.messageDeliveryStatus)
      .build()
  }
  def asReadOnly
      : zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest.ReadOnly =
    zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest
      .wrap(buildAwsValue())
}
object UpdateResourceEventConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotwireless.model.UpdateResourceEventConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest =
      zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest(
        identifier,
        identifierType,
        partnerType.map(value => value),
        deviceRegistrationState.map(value => value.asEditable),
        proximity.map(value => value.asEditable),
        join.map(value => value.asEditable),
        connectionStatus.map(value => value.asEditable),
        messageDeliveryStatus.map(value => value.asEditable)
      )
    def identifier: Identifier
    def identifierType: zio.aws.iotwireless.model.IdentifierType
    def partnerType
        : Optional[zio.aws.iotwireless.model.EventNotificationPartnerType]
    def deviceRegistrationState: Optional[
      zio.aws.iotwireless.model.DeviceRegistrationStateEventConfiguration.ReadOnly
    ]
    def proximity: Optional[
      zio.aws.iotwireless.model.ProximityEventConfiguration.ReadOnly
    ]
    def join
        : Optional[zio.aws.iotwireless.model.JoinEventConfiguration.ReadOnly]
    def connectionStatus: Optional[
      zio.aws.iotwireless.model.ConnectionStatusEventConfiguration.ReadOnly
    ]
    def messageDeliveryStatus: Optional[
      zio.aws.iotwireless.model.MessageDeliveryStatusEventConfiguration.ReadOnly
    ]
    def getIdentifier: ZIO[Any, Nothing, Identifier] = ZIO.succeed(identifier)
    def getIdentifierType
        : ZIO[Any, Nothing, zio.aws.iotwireless.model.IdentifierType] =
      ZIO.succeed(identifierType)
    def getPartnerType: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.EventNotificationPartnerType
    ] = AwsError.unwrapOptionField("partnerType", partnerType)
    def getDeviceRegistrationState: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.DeviceRegistrationStateEventConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "deviceRegistrationState",
      deviceRegistrationState
    )
    def getProximity: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.ProximityEventConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("proximity", proximity)
    def getJoin: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.JoinEventConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("join", join)
    def getConnectionStatus: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.ConnectionStatusEventConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("connectionStatus", connectionStatus)
    def getMessageDeliveryStatus: ZIO[
      Any,
      AwsError,
      zio.aws.iotwireless.model.MessageDeliveryStatusEventConfiguration.ReadOnly
    ] =
      AwsError.unwrapOptionField("messageDeliveryStatus", messageDeliveryStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotwireless.model.UpdateResourceEventConfigurationRequest
  ) extends zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest.ReadOnly {
    override val identifier: Identifier =
      zio.aws.iotwireless.model.primitives.Identifier(impl.identifier())
    override val identifierType: zio.aws.iotwireless.model.IdentifierType =
      zio.aws.iotwireless.model.IdentifierType.wrap(impl.identifierType())
    override val partnerType
        : Optional[zio.aws.iotwireless.model.EventNotificationPartnerType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.partnerType())
        .map(value =>
          zio.aws.iotwireless.model.EventNotificationPartnerType.wrap(value)
        )
    override val deviceRegistrationState: Optional[
      zio.aws.iotwireless.model.DeviceRegistrationStateEventConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.deviceRegistrationState())
      .map(value =>
        zio.aws.iotwireless.model.DeviceRegistrationStateEventConfiguration
          .wrap(value)
      )
    override val proximity: Optional[
      zio.aws.iotwireless.model.ProximityEventConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.proximity())
      .map(value =>
        zio.aws.iotwireless.model.ProximityEventConfiguration.wrap(value)
      )
    override val join
        : Optional[zio.aws.iotwireless.model.JoinEventConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.join())
        .map(value =>
          zio.aws.iotwireless.model.JoinEventConfiguration.wrap(value)
        )
    override val connectionStatus: Optional[
      zio.aws.iotwireless.model.ConnectionStatusEventConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.connectionStatus())
      .map(value =>
        zio.aws.iotwireless.model.ConnectionStatusEventConfiguration.wrap(value)
      )
    override val messageDeliveryStatus: Optional[
      zio.aws.iotwireless.model.MessageDeliveryStatusEventConfiguration.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.messageDeliveryStatus())
      .map(value =>
        zio.aws.iotwireless.model.MessageDeliveryStatusEventConfiguration
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotwireless.model.UpdateResourceEventConfigurationRequest
  ): zio.aws.iotwireless.model.UpdateResourceEventConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
